daily: Convert and export to daily data

Description Usage Arguments Value

View source: R/daily.R

Description

This function takes the output from the site load functions and processed them to daily values. Maximum of 96 records per day or every 15 minutes. Output day is in terms of lubridate date, days since 01 Jan 1970. Daily precipitation is judged by day, temperature is based on 08:00 to 08:00 the following morning.

Usage

1
daily(x)

Arguments

x

data frame from LRLhydromet import command

Value

daily data


LimpopoLab/LRLhydromet documentation built on Dec. 17, 2021, 12:09 a.m.