Description Usage Arguments Value
This function loads the Mutale data and provides some processing, will pass to analysis function for daily data
1 | mutale(apptoken = "null")
|
apptoken |
from Socrata service |
data frame for hydromet station
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.