Description Usage Arguments Value
This function takes the output from the site load functions and processed them to daily values. Maximum of 96 records per day or every 15 minutes. Output day is in terms of lubridate date, days since 01 Jan 1970. Daily precipitation is judged by day, temperature is based on 08:00 to 08:00 the following morning.
1 | daily(x)
|
x |
data frame from LRLhydromet import command |
daily data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.